/* GNOME DB libary
 * Copyright (C) 1999 Rodrigo Moya
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GDA_POSTGRES_COMMAND_H__
#  define __GDA_POSTGRES_COMMAND_H__

#include "gda-postgres-types.h"

Gda_POSTGRES_Command    *gda_postgres_cmd_new (void);
void                     gda_postgres_cmd_free (Gda_POSTGRES_Command *);
Gda_POSTGRES_Connection *gda_postgres_cmd_set_connection (Gda_POSTGRES_Command *,
							  Gda_POSTGRES_Connection *);
Gda_POSTGRES_Recordset  *gda_postgres_cmd_execute (Gda_POSTGRES_Command *,
						   Gda_POSTGRES_Error *,
						   const GDA_CmdParameterSeq *,
						   gulong *affected,
						   gulong );
Gda_POSTGRES_Recordset  *gda_postgres_cmd_execute_from_builtin (Gda_POSTGRES_Command *cmd,
								Gda_Builtin_Result *res,
								gulong *affected);

#endif
